<?php

/**
 * This source file is subject to the GNU GENERAL PUBLIC LICENSE (GPL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.gnu.org/licenses/gpl-3.0.txt
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly

if( !class_exists( 'sheeba_lite_admin_notice' ) ) {

	class sheeba_lite_admin_notice {
	
		/**
		 * Constructor
		 */
		 
		public function __construct( $fields = array() ) {

			if ( 
				!get_option( 'sheeba-lite-hidden-notice') &&
				version_compare( PHP_VERSION, SHEEBA_LITE_MIN_PHP_VERSION, '>=' )
			) {

				add_action( 'admin_notices', array(&$this, 'admin_notice') );
				add_action( 'admin_head', array( $this, 'dismiss' ) );
				add_action( 'admin_init', array(&$this, 'add_script') ,11);

            }

		}

		 /**
		 * Loads the notice style
		 */

		public function add_script() {

			global $wp_version;

			$file_dir = get_template_directory_uri() . '/core/admin/assets/';
			wp_enqueue_style ( 'sheeba-lite-notice', $file_dir.'css/notice.css' );

		}
        
        /**
		 * Dismiss notice.
		 */
		
		public function dismiss() {

			if ( isset( $_GET['sheeba-lite-dismiss'] ) && check_admin_referer( 'sheeba-lite-dismiss-action' ) ) {
		
				update_option( 'sheeba-lite-hidden-notice', intval($_GET['sheeba-lite-dismiss']) );
				remove_action( 'admin_notices', array(&$this, 'admin_notice') );
				
			} 
		
		}

		/**
		 * Admin notice.
		 */
		 
		public function admin_notice() {
			
		?>
			
            <div class="notice notice-warning is-dismissible">

            	<p>
            
            		<strong>

						<?php esc_html_e( 'Unlock all premium features of Sheeba theme like...', 'sheeba-lite' );  ?>

                    </strong>
                
                </p>

                <p class="notice-coupon-message">

					<span class="dashicon dashicons dashicons-yes-alt" size="10"></span><?php esc_html_e( '600+ Google Fonts', 'sheeba-lite' ); ?><br/>
					<span class="dashicon dashicons dashicons-yes-alt" size="10"></span><?php esc_html_e( 'Custom colors', 'sheeba-lite' ); ?><br/>
					<span class="dashicon dashicons dashicons-yes-alt" size="10"></span><?php esc_html_e( 'Unlimited widget areas', 'sheeba-lite' ); ?><br/>
					<span class="dashicon dashicons dashicons-yes-alt" size="10"></span><?php esc_html_e( 'Portfolio section', 'sheeba-lite' ); ?>
                
                </p>

            	<p>
					<strong>
						<?php esc_html_e( 'Get the premium version of Sheeba or choose the Plus plan to use Sheeba as a starter theme for your website', 'sheeba-lite' ); ?>
					</strong><br/>
					<strong><?php esc_html_e( 'You can also select a bundle of 19 WordPress themes', 'sheeba-lite' ); ?></strong>
                </p>

                <p>
					
					<a href="<?php echo esc_url(admin_url( 'themes.php?page=sheeba-lite-welcome-page&section=free_pro' )); ?>" class="button"><?php esc_html_e( 'Free vs Pro', 'sheeba-lite' ); ?></a>

					<a target="_blank" href="<?php echo esc_url( 'https://www.themeinprogress.com/sheeba-flexible-and-and-easy-to-use-wordpress-and-woocommerce-theme/?ref=2&campaign=sheeba-lite-notice' ); ?>" class="button button-primary"><?php esc_html_e( 'Sheeba Pro', 'sheeba-lite' ); ?></a>

					<a target="_blank" href="<?php echo esc_url( 'https://www.themeinprogress.com/wordpress-themes-bundle/?ref=2&campaign=sheeba-lite-notice' ); ?>" class="button button-primary"><?php esc_html_e( 'Bundle of 19 WordPress Themes', 'sheeba-lite' ); ?></a>
					
					<span class="notice-arrow" style="">&#x2938;</span>

				</p>

            	<p>

                    <?php

                        printf( 
                            '<a href="%1$s" class="dismiss-notice">' . esc_html__( 'Dismiss this notice', 'sheeba-lite' ) . '</a>', 
                            esc_url( wp_nonce_url( add_query_arg( 'sheeba-lite-dismiss', '1' ), 'sheeba-lite-dismiss-action'))
                        );

                    ?>
                
            	</p>

            </div>
		
		<?php
		
		}

	}

}

new sheeba_lite_admin_notice();

?>